@@ -214,7 +214,7 @@ int dasd_get_host_access_count(char *device)
 	char *path;
 	long value;
 
-	if (!util_sys_get_dev_addr(device, busid))
+	if (util_sys_get_dev_addr(device, busid) != 0)
 		return 0;
 
 	path = util_path_sysfs("bus/ccw/devices/%s/host_access_count", busid);
