@@ -649,14 +649,12 @@ static void print_defunct_devices(struct util_rec *rec, char *path)
 			snprintf(buf, sizeof(buf), "%s", device);
 		}
 		if (cmd.opt_devrange && cmd.rng_count > 0 &&
-		   !id_in_ranges_list(device)) {
-			util_scandir_free(de_vec, count);
+		   !id_in_ranges_list(device))
 			continue;
-		}
-		if (fill_device_info(rec, path, device) != 0) {
-			util_scandir_free(de_vec, count);
+
+		if (fill_device_info(rec, path, device) != 0)
 			continue;
-		}
+
 		if (cmd.opt_uppercase)
 			util_str_toupper(buf);
 		util_rec_set(rec, "device", "%s", buf);
@@ -719,7 +717,7 @@ static void print_subchannels_of_type(enum sch_type type_requested,
 	if (!cmd.opt_devrange && cmd.rng_count > 0)
 		return;
 	path = util_path_sysfs("devices");
-	count = util_scandir(&de_vec, alphasort, path, "css.*/");
+	count = util_scandir(&de_vec, alphasort, path, "css.*");
 	free(path);
 	for (i = 0; i < count; i++) {
 		path = util_path_sysfs("devices/%s/defunct", de_vec[i]->d_name);
