@@ -3,7 +3,7 @@
  *
  * Generic input dump format functions (DFI - Dump Format Input)
  *
- * Copyright IBM Corp. 2001, 2017
+ * Copyright IBM Corp. 2001, 2018
  *
  * s390-tools is free software; you can redistribute it and/or modify
  * it under the terms of the MIT license. See LICENSE for details.
@@ -21,7 +21,9 @@
 static struct dfi *dfi_vec[] = {
 	&dfi_s390tape,
 	&dfi_devmem,
+	&dfi_s390mv_ext,
 	&dfi_s390mv,
+	&dfi_s390_ext,
 	&dfi_s390,
 	&dfi_lkcd,
 	&dfi_elf,
@@ -70,6 +72,7 @@ struct attr {
 	u32			*real_cpu_cnt;
 	struct new_utsname	*utsname;
 	char			*dump_method;
+	u64			*file_size;
 };
 
 /*
@@ -149,12 +152,46 @@ static void mem_update(struct mem *mem)
 static void mem_map_print(void)
 {
 	struct dfi_mem_chunk *mem_chunk;
+	u64 print_start = 0, print_end = 0;
+	const char *zero_str;
+	u32 volnr = 0;
 
 	STDERR("\nMemory map:\n");
-	dfi_mem_chunk_iterate(mem_chunk) {
-		STDERR("  %016llx - %016llx (%llu MB)\n", mem_chunk->start,
-		       mem_chunk->end, TO_MIB(mem_chunk->size));
+	/*
+	 * Print each memory chunk if verbose specified
+	 */
+	if (g.opts.verbose_specified) {
+		dfi_mem_chunk_iterate(mem_chunk) {
+			zero_str = "";
+			if (mem_chunk->read_fn == dfi_mem_chunk_read_zero)
+				zero_str = " zeroes";
+			STDERR("  %016llx - %016llx (%llu MB%s)\n",
+			       mem_chunk->start, mem_chunk->end,
+			       TO_MIB(mem_chunk->size), zero_str);
+		}
+		return;
 	}
+	/*
+	 * Merge adjacent memory chunks from the same volume
+	 */
+	dfi_mem_chunk_iterate(mem_chunk) {
+		if (print_end == 0) {
+			print_start = mem_chunk->start;
+			print_end = mem_chunk->end;
+			volnr = mem_chunk->volnr;
+			continue;
+		}
+		if (mem_chunk->start != print_end + 1 ||
+		    mem_chunk->volnr != volnr) {
+			STDERR("  %016llx - %016llx (%llu MB)\n", print_start,
+			       print_end, TO_MIB(print_end - print_start + 1));
+			print_start = mem_chunk->start;
+			volnr = mem_chunk->volnr;
+		}
+		print_end = mem_chunk->end;
+	}
+	STDERR("  %016llx - %016llx (%llu MB)\n", print_start,
+	       print_end, TO_MIB(print_end - print_start + 1));
 }
 
 /*
@@ -226,6 +263,9 @@ void dfi_info_print(void)
 	if (l.attr.mem_size_real)
 		STDERR("  Real memory range..: %lld MB\n",
 		      TO_MIB(*l.attr.mem_size_real));
+	if (l.attr.file_size)
+		STDERR("  Dump file size.....: %lld MB\n",
+		      TO_MIB(*l.attr.file_size));
 	if (dfi_mem_range())
 		mem_map_print();
 	if (l.dfi->info_dump) {
@@ -351,9 +391,27 @@ void dfi_mem_chunk_virt_add(u64 start, u64 size, void *data,
 			    dfi_mem_chunk_read_fn read_fn,
 			    dfi_mem_chunk_free_fn free_fn)
 {
+	if (size == 0)
+		return;
 	mem_chunk_create(&l.mem_virt, start, size, data, read_fn, free_fn);
 }
 
+/*
+ * Add memory chunk with volume index
+ */
+void dfi_mem_chunk_add_vol(u64 start, u64 size, void *data,
+			   dfi_mem_chunk_read_fn read_fn,
+			   dfi_mem_chunk_free_fn free_fn,
+			   u32 volnr)
+{
+	if (size == 0)
+		return;
+	mem_chunk_create(&l.mem_phys, start, size, data, read_fn, free_fn);
+	mem_chunk_create(&l.mem_virt, start, size, data, read_fn, free_fn);
+	l.mem_virt.chunk_cache->volnr = volnr;
+
+}
+
 /*
  * Add memory chunk
  */
@@ -361,8 +419,16 @@ void dfi_mem_chunk_add(u64 start, u64 size, void *data,
 		       dfi_mem_chunk_read_fn read_fn,
 		       dfi_mem_chunk_free_fn free_fn)
 {
-	mem_chunk_create(&l.mem_phys, start, size, data, read_fn, free_fn);
-	mem_chunk_create(&l.mem_virt, start, size, data, read_fn, free_fn);
+	dfi_mem_chunk_add_vol(start, size, data, read_fn, free_fn, 0);
+}
+
+/*
+ * Read zero pages
+ */
+void dfi_mem_chunk_read_zero(struct dfi_mem_chunk *UNUSED(mem_chunk),
+			     u64 UNUSED(off), void *buf, u64 cnt)
+{
+	memset(buf, 0, cnt);
 }
 
 /*
@@ -401,6 +467,16 @@ struct dfi_mem_chunk *dfi_mem_chunk_first(void)
 	return util_list_start(&l.mem_virt.chunk_list);
 }
 
+/*
+ * Return last memory chunk
+ */
+struct dfi_mem_chunk *dfi_mem_chunk_last(void)
+{
+	if (util_list_is_empty(&l.mem_virt.chunk_list))
+		return NULL;
+	return util_list_end(&l.mem_virt.chunk_list);
+}
+
 /*
  * Return next memory chunk
  */
@@ -678,7 +754,7 @@ struct new_utsname *dfi_attr_utsname(void)
 }
 
 /*
- * Attribute: dump method
+ * Attribute: Dump method
  */
 void dfi_attr_dump_method_set(char *dump_method)
 {
@@ -704,6 +780,21 @@ u64 *dfi_attr_mem_size_real(void)
 	return l.attr.mem_size_real;
 }
 
+/*
+ * Attribute: Dump file size
+ */
+void dfi_attr_file_size_set(u64 file_size)
+{
+	l.attr.file_size = zg_alloc(sizeof(*l.attr.file_size));
+	*l.attr.file_size = file_size;
+}
+
+u64 *dfi_attr_file_size(void)
+{
+	return l.attr.file_size;
+}
+
+
 /*
  * Attribute: Build architecture
  */
@@ -795,7 +886,10 @@ static void lc2cpu_64(struct dfi_cpu *cpu, struct dfi_lowcore_64 *lc)
 	/* Add VX registers if available */
 	if (!dfi_cpu_lc_has_vx_sa(lc))
 		return;
-	dfi_mem_read(lc->vector_save_area_addr, &vx_sa, sizeof(vx_sa));
+	if (dfi_mem_read_rc(lc->vector_save_area_addr, &vx_sa, sizeof(vx_sa))) {
+		STDERR("zgetdump: Vector registers save area is beyond dump memory limit for CPU %d\n", cpu->cpu_id);
+		return;
+	}
 	memcpy(cpu->vxrs_high, &vx_sa[16 * 16], sizeof(cpu->vxrs_high));
 	for (i = 0; i < 16; i++)
 		memcpy(&cpu->vxrs_low[i], &vx_sa[16 * i + 8], sizeof(u64));
@@ -827,6 +921,7 @@ void dfi_cpu_add_from_lc(u32 lc_addr)
 {
 	struct dfi_cpu *cpu = dfi_cpu_alloc();
 
+	cpu->cpu_id = l.cpus.cnt;
 	switch (l.cpus.content) {
 	case DFI_CPU_CONTENT_LC:
 		cpu->prefix = lc_addr;
