@@ -12,7 +12,7 @@
 #include "cio.h"
 #include "eckd2dump.h"
 #include "error.h"
-#include "s390.h"
+#include "boot/s390.h"
 #include "stage2dump.h"
 
 #define ECKD_CCW_LOCATE_RECORD		0x47
