@@ -81,6 +81,7 @@ struct command_line {
 	int add_files;
 	int dry_run;
 	int force;
+	int is_secure;
 	enum scan_section_type type;
 };
 
@@ -98,6 +99,22 @@ store_option(struct command_line* cmdline, enum scan_keyword_id keyword,
 	return 0;
 }
 
+static int
+set_secure_ipl(char *keyword, int *is_secure)
+{
+	if (strcmp(keyword, "auto") == 0) {
+		*is_secure = SECURE_BOOT_AUTO;
+	} else if (strcmp(keyword, "0") == 0) {
+		*is_secure = SECURE_BOOT_DISABLED;
+	} else if (strcmp(keyword, "1") == 0) {
+		*is_secure = SECURE_BOOT_ENABLED;
+	} else {
+		error_reason("Invalid secure boot setting '%s'",
+			     keyword);
+		return -1;
+	}
+	return 0;
+}
 
 static int
 get_command_line(int argc, char* argv[], struct command_line* line)
@@ -111,6 +128,7 @@ get_command_line(int argc, char* argv[], struct command_line* line)
 	memset((void *) &cmdline, 0, sizeof(struct command_line));
 	cmdline.type = section_invalid;
 	is_keyword = 0;
+	cmdline.is_secure = SECURE_BOOT_UNDEFINED;
 	/* Process options */
 	do {
 		opt = getopt_long(argc, argv, option_string, options, NULL);
@@ -226,9 +244,7 @@ get_command_line(int argc, char* argv[], struct command_line* line)
 				cmdline.menu = optarg;
 			break;
 		case 'S':
-			is_keyword = 1;
-			rc = store_option(&cmdline, scan_keyword_secure,
-					  optarg);
+			rc = set_secure_ipl(optarg, &cmdline.is_secure);
 			break;
 		case 'h':
 			cmdline.help = 1;
@@ -1049,6 +1065,21 @@ check_job_mvdump_data(struct job_mvdump_data* dump, char* name)
 	return 0;
 }
 
+static int
+check_secure_boot(struct job_data *job)
+{
+	switch (job->is_secure) {
+	case SECURE_BOOT_UNDEFINED:
+	case SECURE_BOOT_DISABLED:
+	case SECURE_BOOT_ENABLED:
+	case SECURE_BOOT_AUTO:
+		return 0;
+	default:
+		error_reason("Invalid secure boot setting '%d'",
+			     job->is_secure);
+		return -1;
+	}
+}
 
 static int
 check_job_data(struct job_data* job)
@@ -1093,6 +1124,8 @@ check_job_data(struct job_data* job)
 	case job_mvdump:
 		rc = check_job_mvdump_data(&job->data.mvdump, job->name);
 	}
+	if (!rc)
+		rc = check_secure_boot(job);
 	return rc;
 }
 
@@ -1278,27 +1311,6 @@ type_from_target(char *target, disk_type_t *type)
 	}
 }
 
-static int
-set_secure_ipl(char *keyword, struct job_data *job)
-{
-	if (strcmp(keyword, "auto") == 0) {
-		job->is_secure = SECURE_BOOT_AUTO;
-	} else if (strcmp(keyword, "0") == 0) {
-		job->is_secure = SECURE_BOOT_DISABLED;
-	} else if (strcmp(keyword, "1") == 0) {
-		if (job->target.targettype != disk_type_scsi) {
-			error_reason("Secure boot forced for non-SCSI disk type");
-			return -1;
-		}
-		job->is_secure = SECURE_BOOT_ENABLED;
-	} else {
-		error_reason("Invalid secure boot setting '%s'",
-			     keyword);
-		return -1;
-	}
-	return 0;
-}
-
 static int
 get_job_from_section_data(char* data[], struct job_data* job, char* section)
 {
@@ -1383,7 +1395,7 @@ get_job_from_section_data(char* data[], struct job_data* job, char* section)
 		/* Fill in secure boot */
 		if (data[(int) scan_keyword_secure] != NULL) {
 			rc = set_secure_ipl(data[(int) scan_keyword_secure],
-					    job);
+					    &job->is_secure);
 			if (rc)
 				return rc;
 		}
@@ -1547,7 +1559,7 @@ get_menu_job(struct scan_token* scan, char* menu, struct job_data* job)
 				case scan_keyword_secure:
 					rc = set_secure_ipl(
 						scan[i].content.keyword.value,
-						job);
+						&job->is_secure);
 					if (rc)
 						return rc;
 					break;
@@ -1609,6 +1621,7 @@ get_menu_job(struct scan_token* scan, char* menu, struct job_data* job)
 	       sizeof(struct job_menu_entry) * job->data.menu.num);
 	/* Fill in data */
 	current = 0;
+	job->data.menu.entry->is_secure = SECURE_BOOT_UNDEFINED;
 	for (i=index+1; (scan[i].id != scan_id_empty) &&
 			(scan[i].id != scan_id_section_heading) &&
 			(scan[i].id != scan_id_menu_heading); i++) {
@@ -1640,6 +1653,7 @@ get_menu_job(struct scan_token* scan, char* menu, struct job_data* job)
 		if (temp_job == NULL)
 			return -1;
 		memset((void *) temp_job, 0, sizeof(struct job_data));
+		temp_job->is_secure = SECURE_BOOT_UNDEFINED;
 		rc = get_job_from_section_data(data, temp_job,
 					job->data.menu.entry[current].name);
 		if (rc) {
@@ -1652,6 +1666,8 @@ get_menu_job(struct scan_token* scan, char* menu, struct job_data* job)
 				job->data.menu.entry[current].id = job_ipl;
 				job->data.menu.entry[current].data.ipl =
 					temp_job->data.ipl;
+				job->data.menu.entry[current].is_secure =
+					temp_job->is_secure;
 				memset((void *) &temp_job->data.ipl, 0,
 				       sizeof(struct job_ipl_data));
 				break;
@@ -1858,12 +1874,8 @@ get_job_from_config_file(struct command_line* cmdline, struct job_data* job)
 		scan_free(scan);
 		return rc;
 	}
-	rc = scan_check_bls(scan);
-	if (rc) {
-		error_text("BLS parsing '%s'", blsdir);
-		scan_free(scan);
-		return rc;
-	}
+	/* maybe we need to update bls search path with target path */
+	scan_update_bls_path(scan);
 	/* Get job from config file data */
 	if (cmdline->menu != NULL)
 		rc = get_menu_job(scan, cmdline->menu, job);
@@ -1904,7 +1916,7 @@ job_get(int argc, char* argv[], struct job_data** data)
 	job->add_files = cmdline.add_files;
 	job->data.mvdump.force = cmdline.force;
 	job->dry_run = cmdline.dry_run;
-	job->is_secure = SECURE_BOOT_AUTO;
+	job->is_secure =  SECURE_BOOT_UNDEFINED;
 	/* Get job data from user input */
 	if (cmdline.help) {
 		job->command_line = 1;
@@ -1923,6 +1935,11 @@ job_get(int argc, char* argv[], struct job_data** data)
 		job_free(job);
 		return rc;
 	}
+	if (cmdline.is_secure != SECURE_BOOT_UNDEFINED)
+		job->is_secure = cmdline.is_secure;
+	else if (job->id != job_menu && job->is_secure == SECURE_BOOT_UNDEFINED)
+		job->is_secure = SECURE_BOOT_AUTO;
+
 	/* Check job data for validity */
 	rc = check_job_data(job);
 	if (rc) {
