@@ -45,8 +45,6 @@
 
 #define MAX_CIPHER_LEN		32
 
-#define DEFAULT_KEYBITS		256
-
 #define INITIAL_APQN_ENTRIES	16
 
 /**
@@ -1394,7 +1392,7 @@ int generate_key_verification_pattern(const u8 *key, size_t key_size,
 		goto out;
 	}
 
-	opfd = accept(tfmfd, NULL, 0);
+	opfd = accept(tfmfd, NULL, NULL);
 	if (opfd < 0) {
 		rc = -errno;
 		pr_verbose(verbose, "Failed to accept on the AF_ALG socket");
@@ -1775,10 +1773,6 @@ int check_aes_cipher_key(const u8 *key, size_t key_size)
 		       "decryption\n");
 		mismatch = true;
 	}
-	if (cipherkey->kuf1 & 0x2000) {
-		printf("INFO: The secure key can be used for data translate\n");
-		mismatch = true;
-	}
 	if (cipherkey->kuf1 & 0x1000) {
 		printf("WARNING: The secure key can only be used in UDXs\n");
 		mismatch = true;
@@ -1929,8 +1923,8 @@ static int reencipher_ep11_secure_key(struct ep11_lib *ep11, u8 *secure_key,
 				      u8 *mkvp, bool *apqn_selected,
 				      bool verbose)
 {
+	unsigned int card, domain;
 	unsigned int flags;
-	int card, domain;
 	target_t target;
 	int rc;
 
